pytilities.geometry.immutablerectangle — Pytilities 1.2.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities 1.2.0 documentation »
- API documentation »
- pytilities »
- pytilities.geometry »

# pytilities.geometry.immutablerectangle

`pytilities.geometry.immutablerectangle.` `ImmutableRectangle`

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities 1.2.0 documentation »
- API documentation »
- pytilities »
- pytilities.geometry »